@@ -20,22 +20,6 @@ import sys
 
 import eventlet
 
-from oslo_concurrency import processutils
-from oslo_config import cfg
-from oslo_log import log as logging
-from oslo_service import service
-
-from murano.api.v1 import request_statistics
-from murano.common import app_loader
-from murano.common import config
-from murano.common import policy
-from murano.common import server
-from murano.common import statservice as stats
-from murano.common import wsgi
-
-CONF = cfg.CONF
-
-
 if os.name == 'nt':
     # eventlet monkey patching causes subprocess.Popen to fail on Windows
     # when using pipes due to missing non blocking I/O support
@@ -49,26 +33,31 @@ root = os.path.join(os.path.abspath(__file__), os.pardir, os.pardir, os.pardir)
 if os.path.exists(os.path.join(root, 'murano', '__init__.py')):
     sys.path.insert(0, root)
 
+from murano.api.v1 import request_statistics
+from murano.common import config
+from murano.common import policy
+from murano.common import server
+from murano.common import statservice as stats
+from murano.common import wsgi
+from murano.openstack.common import log
+from murano.openstack.common import service
+
 
 def main():
     try:
         config.parse_args()
-        config.set_middleware_defaults()
+        log.setup('murano')
         request_statistics.init_stats()
         policy.init()
 
-        logging.setup(CONF, 'murano')
-        workers = CONF.murano.api_workers
-        if not workers:
-            workers = processutils.get_worker_count()
-        launcher = service.launch(
-            CONF, server.ApiService(),
-            workers=workers, restart_method='mutate')
+        launcher = service.ServiceLauncher()
+
+        app = config.load_paste_app('murano')
+        port, host = (config.CONF.bind_port, config.CONF.bind_host)
 
-        app = app_loader.load_paste_app('murano')
-        port, host = (CONF.bind_port, CONF.bind_host)
         launcher.launch_service(wsgi.Service(app, port, host))
-        launcher.launch_service(server.NotificationService())
+        launcher.launch_service(server.get_rpc_service())
+        launcher.launch_service(server.get_notification_service())
         launcher.launch_service(stats.StatsCollectingService())
 
         launcher.wait()
