@@ -19,7 +19,7 @@ import types
 import eventlet
 import jsonschema
 
-from murano.openstack.common.gettextutils import _  # noqa
+from murano.common.i18n import _, _LI
 from murano.openstack.common import log as logging
 
 
@@ -240,7 +240,7 @@ def retry(ExceptionToCheck, tries=4, delay=3, backoff=2):
                 except ExceptionToCheck as e:
 
                     LOG.exception(e)
-                    LOG.info(_("Retrying in {0} seconds...").format(mdelay))
+                    LOG.info(_LI("Retrying in {0} seconds...").format(mdelay))
 
                     eventlet.sleep(mdelay)
 
