@@ -15,15 +15,17 @@
 """Session management functions."""
 import threading
 
-from oslo_config import cfg
-from oslo_db import exception
-from oslo_db import options
-from oslo_db.sqlalchemy import session as db_session
-from oslo_utils import timeutils
+from oslo.db import exception
+from oslo.db import options
+from oslo.db.sqlalchemy import session as db_session
+from oslo.utils import timeutils
 
-from murano.db import models
+from murano.common import config
+from murano.db.models import Lock
+from murano.openstack.common import log as logging
 
-CONF = cfg.CONF
+LOG = logging.getLogger(__name__)
+CONF = config.CONF
 
 options.set_defaults(CONF)
 
@@ -37,9 +39,6 @@ def _create_facade_lazily():
     global _LOCK, _FACADE
 
     if _FACADE is None:
-        # FIXME(zigo): autocommit=True it's not compatible with
-        # SQLAlchemy 2.0, and will be removed in future
-        _FACADE = db_session.EngineFacade.from_config(CONF, autocommit=True)
         with _LOCK:
             if _FACADE is None:
                 _FACADE = db_session.EngineFacade.from_config(CONF,
@@ -71,11 +70,11 @@ def _get_or_create_lock(name, session, nested, retry=0):
         session.begin_nested()
     else:
         session.begin()
-    existing = session.query(models.Lock).get(name)
+    existing = session.query(Lock).get(name)
     if existing is None:
         try:
             # no lock found, creating a new one
-            lock = models.Lock(id=name, ts=timeutils.utcnow())
+            lock = Lock(id=name, ts=timeutils.utcnow())
             lock.save(session)
             return session.transaction
             # lock created and acquired
