@@ -16,6 +16,7 @@ import os
 import shutil
 import sys
 import types
+
 import yaml
 
 from murano.dsl import yaql_expression
@@ -115,12 +116,12 @@ class HotPackage(murano.packages.application_package.ApplicationPackage):
         contract = '$'
 
         parameter_type = value['type']
-        if parameter_type == 'string':
+        if parameter_type in ('string', 'comma_delimited_list', 'json'):
             contract += '.string()'
         elif parameter_type == 'number':
             contract += '.int()'
-        elif parameter_type == 'json':
-            contract += '.object()'
+        elif parameter_type == 'boolean':
+            contract += '.bool()'
         else:
             raise ValueError('Unsupported parameter type ' + parameter_type)
 
@@ -204,6 +205,10 @@ class HotPackage(murano.packages.application_package.ApplicationPackage):
         for key, value in (hot.get('parameters') or {}).items():
             template_parameters[key] = YAQL("$." + key)
 
+        copy_outputs = []
+        for key, value in (hot.get('outputs') or {}).items():
+            copy_outputs.append({YAQL('$.' + key): YAQL('$outputs.' + key)})
+
         deploy = [
             {YAQL('$environment'): YAQL(
                 "$.find('io.murano.Environment').require()"
@@ -233,17 +238,28 @@ class HotPackage(murano.packages.application_package.ApplicationPackage):
 
             YAQL("$reporter.report($this, "
                  "'Stack creation has started')"),
-            YAQL('$stack.push()'),
-            {YAQL('$outputs'): YAQL('$stack.output()')},
-            YAQL("$reporter.report($this, "
-                 "'Stack was successfully created')"),
+            {
+                'Try': [YAQL('$stack.push()')],
+                'Catch': [
+                    {
+                        'As': 'e',
+                        'Do': [
+                            YAQL("$reporter.report_error($this, $e.message)"),
+                            {'Rethrow': None}
+                        ]
+                    }
+                ],
+                'Else': [
+                    {YAQL('$outputs'): YAQL('$stack.output()')},
+                    {'Do': copy_outputs},
+                    YAQL("$reporter.report($this, "
+                         "'Stack was successfully created')"),
 
-            YAQL("$reporter.report($this, "
-                 "'Application deployment has finished')"),
+                    YAQL("$reporter.report($this, "
+                         "'Application deployment has finished')"),
+                ]
+            }
         ]
-        for key, value in (hot.get('outputs') or {}).items():
-            deploy.append({YAQL('$.' + key): YAQL(
-                '$outputs.' + key)})
 
         destroy = [
             {YAQL('$stack'): YAQL(
@@ -294,10 +310,15 @@ class HotPackage(murano.packages.application_package.ApplicationPackage):
             'label': name.title().replace('_', ' ')
         }
         parameter_type = parameter_spec['type']
-        if parameter_type == 'string':
-            translated['type'] = 'string'
-        elif parameter_type == 'number':
+        if parameter_type == 'number':
             translated['type'] = 'integer'
+        elif parameter_type == 'boolean':
+            translated['type'] = 'boolean'
+        else:
+            # string, json, and comma_delimited_list parameters are all
+            # displayed as strings in UI. Any unsuported parameter would also
+            # be displayed as strings.
+            translated['type'] = 'string'
 
         if 'description' in parameter_spec:
             translated['description'] = parameter_spec['description']
@@ -403,5 +424,4 @@ class HotPackage(murano.packages.application_package.ApplicationPackage):
                 }
             ]
         }
-
         return translated
